@@ -246,7 +246,7 @@ DataInput::DataInput()
 
    averageDiff(new Lum::Model::String(L"")),
    summary(new Lum::Model::String(L"")),
-   entries(new Lum::Model::ListTable(3)),
+   entries(new Lum::Model::ListTable()),
    entrySelection(new Lum::Model::SingleLineSelection()),
 
    trend(new Lum::Model::Int(Trend::none))
@@ -271,7 +271,6 @@ DataInput::DataInput()
 
 void DataInput::CalcSize()
 {
-  Lum::Button           *button;
   Lum::DateSelect       *dateSelect;
   Lum::Menu             *menu;
   Lum::Panel            *et;
@@ -285,13 +284,8 @@ void DataInput::CalcSize()
 
   // Date select
 
-  ds=new Lum::HPanel();
-  ds->SetFlex(true,false);
-
-  button=new Lum::Button(L"_<");
-  button->SetModel(prevDayAction);
-  ds->Add(button);
-
+  ds=Lum::HPanel::Create(true,false);
+  ds->Add(Lum::Button::Create(L"_<",prevDayAction));
   ds->Add(new Lum::HSpace(Lum::Space::sizeSmall));
 
   dateSelect=new Lum::DateSelect();
@@ -299,36 +293,26 @@ void DataInput::CalcSize()
   ds->Add(dateSelect);
 
   ds->Add(new Lum::HSpace(Lum::Space::sizeSmall));
-
-  button=new Lum::Button(L"_>");
-  button->SetModel(nextDayAction);
-  ds->Add(button);
-
-  ds->Add(new Lum::HSpace());
+  ds->Add(Lum::Button::Create(L"_>",nextDayAction));
+  ds->AddSpace();
 
   trend=new Trend();
   trend->SetModel(this->trend);
   ds->Add(trend);
 
-  ds->Add(new Lum::HSpace());
+  ds->AddSpace();
 
-  text=new Lum::TextValue();
-  text->SetFlex(true,false);
-  text->SetAlignment(Lum::TextValue::left);
+  text=Lum::TextValue::Create(averageDiff,Lum::TextValue::left,true,false);
   text->SetMinWidth(Lum::Base::Size::stdCharWidth,6);
-  text->SetModel(averageDiff);
   ds->Add(text);
 
-  ds->Add(new Lum::HSpace());
+  ds->AddSpace();
 
-  text=new Lum::TextValue();
-  text->SetFlex(true,false);
-  text->SetAlignment(Lum::TextValue::right);
+  text=Lum::TextValue::Create(summary,Lum::TextValue::right,true,false);
   text->SetMinWidth(Lum::Base::Size::stdCharWidth,9);
-  text->SetModel(summary);
   ds->Add(text);
 
-  ds->Add(new Lum::HSpace(true));
+  ds->AddSpace(true);
   /*
   button=new Lum::Button(L"+F");
   button->SetModel(addFoodAction);
@@ -336,20 +320,13 @@ void DataInput::CalcSize()
 
   ds->Add(new Lum::HSpace(Lum::Space::sizeSmall));*/
 
-  button=new Lum::Button(L"+");
-  button->SetModel(addWeightAction);
-  ds->Add(button);
-
+  ds->Add(Lum::Button::Create(L"+",addWeightAction));
   ds->Add(new Lum::HSpace(Lum::Space::sizeSmall));
-
-  button=new Lum::Button(L"-");
-  button->SetModel(removeItemAction);
-  ds->Add(button);
+  ds->Add(Lum::Button::Create(L"-",removeItemAction));
 
   // Entries table
 
-  et=new Lum::HPanel();
-  et->SetFlex(true,true);
+  et=Lum::HPanel::Create(true,true);
 
   headerModel=new Lum::Model::HeaderImpl();
   headerModel->AddColumn(_(L"ENTRIES_TABLE_HEADER_TIME",L"Time"),Lum::Base::Size::stdCharWidth,5);
@@ -376,13 +353,12 @@ void DataInput::CalcSize()
 
   // Layout comonents
 
-  horiz=new Lum::HPanel();
+  horiz=Lum::HPanel::Create();
 
-  vert=new Lum::VPanel();
-  vert->SetFlex(true,true);
+  vert=Lum::VPanel::Create(true,true);
 
   vert->Add(ds);
-  vert->Add(new Lum::VSpace());
+  vert->AddSpace();
   vert->Add(et);
 
   horiz->Add(vert);
