@@ -47,8 +47,7 @@ Diagram::Diagram()
    valueGoodFrameColor(0.64,0.64,0.64,Lum::OS::display->blackColor),
    valueBadColor(1.0,0.82,0.82,Lum::OS::display->blackColor),
    valueBadFrameColor(0.8,0.58,0.58,Lum::OS::display->blackColor),
-   font(Lum::OS::display->GetFont(Lum::OS::Display::fontTypeProportional,
-                                  Lum::OS::Display::fontScaleFootnote)),
+   font(Lum::OS::display->GetFont(Lum::OS::Display::fontScaleFootnote)),
    mode(modeFullDay)
 {
   SetBackground(Lum::OS::display->GetFill(Lum::OS::Display::graphBackgroundFillIndex));
@@ -67,6 +66,14 @@ Diagram::Diagram()
   Observe(date);
 }
 
+void Diagram::UpdateDimensions()
+{
+  size_t dayWidth=GetDayWidth();
+
+  hAdjustment->SetDimension(width,std::max(width,data.GetDaysCovered()*dayWidth));
+  hAdjustment->SetStepSize(dayWidth);
+}
+
 void Diagram::CalcSize()
 {
   size_t digitWidth=0;
@@ -485,9 +492,6 @@ void Diagram::Draw(int x, int y, size_t w, size_t h)
 
   size_t dayWidth=GetDayWidth();
 
-  hAdjustment->SetDimension(width,std::max(width,data.GetDaysCovered()*dayWidth));
-  hAdjustment->SetStepSize(dayWidth);
-
   if (!adjusted) {
     SyncGraphWithDate();
     adjusted=true;
@@ -495,8 +499,6 @@ void Diagram::Draw(int x, int y, size_t w, size_t h)
 
   /* --- */
 
-  DrawBackground(x,y,w,h);
-
   Lum::OS::DrawInfo   *draw=GetDrawInfo();
   Lum::Base::Calendar start=data.GetStartDate();
   Lum::Base::Calendar end;
