@@ -20,6 +20,7 @@
 #include "FoodInput.h"
 
 #include <Lum/Base/L10N.h>
+#include <Lum/Base/String.h>
 
 #include <Lum/Array.h>
 #include <Lum/Button.h>
@@ -338,14 +339,26 @@ void FoodInput::CalcSize()
 void FoodInput::UpdateFoods()
 {
   std::wstring filter=foodSearch->Get();
+
+  Lum::Base::ToLower(filter);
+
   // Food
   foods->Off();
 
   foods->Clear();
   for (std::set<Food>::iterator iter=data.foods.begin(); iter!=data.foods.end(); ++iter) {
-    if (filter.empty() || iter->name.find(filter)!=std::wstring::npos) {
+    if (filter.empty()) {
       foods->Append(new FoodsEntry(foods,&*iter));
     }
+    else {
+      std::wstring tmp(iter->name);
+
+      Lum::Base::ToLower(tmp);
+
+      if (tmp.find(filter)!=std::wstring::npos) {
+        foods->Append(new FoodsEntry(foods,&*iter));
+      }
+    }
   }
 
   foods->Sort(1);
