@@ -24,7 +24,6 @@
 #include <Lum/Dialog.h>
 #include <Lum/Menu.h>
 #include <Lum/Panel.h>
-#include <Lum/Space.h>
 #include <Lum/Tab.h>
 #include <Lum/View.h>
 
@@ -93,13 +92,10 @@ public:
   {
     Lum::Panel *panel;
     Lum::Tab   *tab;
-    Lum::View  *view;
 
-    panel=new Lum::VPanel();
-    panel->SetFlex(true,true);
+    panel=Lum::VPanel::Create(true,true);
 
-    tab=new Lum::Tab();
-    tab->SetFlex(true,true);
+    tab=Lum::Tab::Create(true,true);
     tab->SetModel(currentTab);
 
     foodInput=new FoodInput();
@@ -112,14 +108,10 @@ public:
 
     tab->Add(_(L"MAIN_TAB_INPUT",L"Day view"),dataInput);
 
-    view=new Lum::View();
-    view->SetFlex(true,true);
-
     diagram=new Diagram();
     diagram->SetFlex(true,true);
-    view->SetObject(diagram);
 
-    tab->Add(_(L"MAIN_TAB_DIAGRAM",L"Diagram"),view);
+    tab->Add(_(L"MAIN_TAB_DIAGRAM",L"Diagram"),Lum::View::Create(diagram,true,true));
 
     panel->Add(tab);
 
